==> jc-1.4.0.tar.gz: soot/toolkits/graph/CompleteBlockGraph.h <==
// public class soot.toolkits.graph.CompleteBlockGraph

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 340ee84e9e1f189d soot_toolkits_graph_BlockGraph
// @dep_class 782877ba15b64cdb soot_toolkits_graph_CompleteBlockGraph

// header file dependencies
// @dep_header soot_toolkits_graph_BlockGraph

#include "soot/toolkits/graph/BlockGraph.h"

#ifndef _JC_soot_toolkits_graph_CompleteBlockGraph_H_
#define _JC_soot_toolkits_graph_CompleteBlockGraph_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Body$object;

// Typedefs
typedef struct _jc_soot_toolkits_graph_CompleteBlockGraph$sub_refs	_jc_soot_toolkits_graph_CompleteBlockGraph$sub_refs;
typedef struct _jc_soot_toolkits_graph_CompleteBlockGraph$sub_nonrefs	_jc_soot_toolkits_graph_CompleteBlockGraph$sub_nonrefs;
typedef struct _jc_soot_toolkits_graph_CompleteBlockGraph$refs	_jc_soot_toolkits_graph_CompleteBlockGraph$refs;
typedef struct _jc_soot_toolkits_graph_CompleteBlockGraph$nonrefs	_jc_soot_toolkits_graph_CompleteBlockGraph$nonrefs;
typedef struct _jc_soot_toolkits_graph_CompleteBlockGraph$object	_jc_soot_toolkits_graph_CompleteBlockGraph$object;

typedef const struct _jc_soot_toolkits_graph_CompleteBlockGraph$vmethods	_jc_soot_toolkits_graph_CompleteBlockGraph$vmethods;
typedef const struct _jc_soot_toolkits_graph_CompleteBlockGraph$vtable	_jc_soot_toolkits_graph_CompleteBlockGraph$vtable;
typedef const struct _jc_soot_toolkits_graph_CompleteBlockGraph$vtype	_jc_soot_toolkits_graph_CompleteBlockGraph$vtype;

// Constructors
extern void _jc_soot_toolkits_graph_CompleteBlockGraph$method$_init$3a6465c484af9c25(_jc_env *, struct _jc_soot_toolkits_graph_CompleteBlockGraph$object *, struct _jc_soot_Body$object *);

// Virtual methods structure
struct _jc_soot_toolkits_graph_CompleteBlockGraph$vmethods {
};

// Vtable
struct _jc_soot_toolkits_graph_CompleteBlockGraph$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_graph_BlockGraph$vmethods	soot_toolkits_graph_BlockGraph;
	_jc_soot_toolkits_graph_CompleteBlockGraph$vmethods	soot_toolkits_graph_CompleteBlockGraph;
};

// Vtype
struct _jc_soot_toolkits_graph_CompleteBlockGraph$vtype {
	_jc_type			type;
	_jc_soot_toolkits_graph_CompleteBlockGraph$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_graph_CompleteBlockGraph$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_toolkits_graph_CompleteBlockGraph$refs {
    _jc_soot_toolkits_graph_CompleteBlockGraph$sub_refs	soot_toolkits_graph_CompleteBlockGraph;
    _jc_soot_toolkits_graph_BlockGraph$sub_refs	soot_toolkits_graph_BlockGraph;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_graph_CompleteBlockGraph$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_graph_CompleteBlockGraph$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_graph_BlockGraph$sub_nonrefs	soot_toolkits_graph_BlockGraph;
    _jc_soot_toolkits_graph_CompleteBlockGraph$sub_nonrefs	soot_toolkits_graph_CompleteBlockGraph;
};

// Object instance structure
struct _jc_soot_toolkits_graph_CompleteBlockGraph$object {
	_jc_soot_toolkits_graph_CompleteBlockGraph$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_graph_CompleteBlockGraph$vtype	*vtype;
	_jc_soot_toolkits_graph_CompleteBlockGraph$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_graph_CompleteBlockGraph$vtype _jc_soot_toolkits_graph_CompleteBlockGraph$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_graph_CompleteBlockGraph, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_graph_CompleteBlockGraph$class_object;

#endif	/* _JC_soot_toolkits_graph_CompleteBlockGraph_H_ */

==> jc-1.4.6.tar.gz: soot/toolkits/graph/CompleteBlockGraph.h <==
// public class soot.toolkits.graph.CompleteBlockGraph

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 340ee84e9e1f189d soot_toolkits_graph_BlockGraph
// @dep_class 782877ba15b64cdb soot_toolkits_graph_CompleteBlockGraph

// header file dependencies
// @dep_header soot_toolkits_graph_BlockGraph

#include "soot/toolkits/graph/BlockGraph.h"

#ifndef _JC_soot_toolkits_graph_CompleteBlockGraph_H_
#define _JC_soot_toolkits_graph_CompleteBlockGraph_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Body$object;

// Typedefs
typedef struct _jc_soot_toolkits_graph_CompleteBlockGraph$sub_refs	_jc_soot_toolkits_graph_CompleteBlockGraph$sub_refs;
typedef struct _jc_soot_toolkits_graph_CompleteBlockGraph$sub_nonrefs	_jc_soot_toolkits_graph_CompleteBlockGraph$sub_nonrefs;
typedef struct _jc_soot_toolkits_graph_CompleteBlockGraph$refs	_jc_soot_toolkits_graph_CompleteBlockGraph$refs;
typedef struct _jc_soot_toolkits_graph_CompleteBlockGraph$nonrefs	_jc_soot_toolkits_graph_CompleteBlockGraph$nonrefs;
typedef struct _jc_soot_toolkits_graph_CompleteBlockGraph$object	_jc_soot_toolkits_graph_CompleteBlockGraph$object;

typedef const struct _jc_soot_toolkits_graph_CompleteBlockGraph$vmethods	_jc_soot_toolkits_graph_CompleteBlockGraph$vmethods;
typedef const struct _jc_soot_toolkits_graph_CompleteBlockGraph$vtable	_jc_soot_toolkits_graph_CompleteBlockGraph$vtable;
typedef const struct _jc_soot_toolkits_graph_CompleteBlockGraph$vtype	_jc_soot_toolkits_graph_CompleteBlockGraph$vtype;

// Constructors
extern void _jc_soot_toolkits_graph_CompleteBlockGraph$method$_init$3a6465c484af9c25(_jc_env *, struct _jc_soot_toolkits_graph_CompleteBlockGraph$object *, struct _jc_soot_Body$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_toolkits_graph_CompleteBlockGraph$vmethods {
};

// Vtable
struct _jc_soot_toolkits_graph_CompleteBlockGraph$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_graph_BlockGraph$vmethods	soot_toolkits_graph_BlockGraph;
	_jc_soot_toolkits_graph_CompleteBlockGraph$vmethods	soot_toolkits_graph_CompleteBlockGraph;
};

// Vtype
struct _jc_soot_toolkits_graph_CompleteBlockGraph$vtype {
	_jc_type			type;
	_jc_soot_toolkits_graph_CompleteBlockGraph$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_graph_CompleteBlockGraph$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_toolkits_graph_CompleteBlockGraph$refs {
    _jc_soot_toolkits_graph_CompleteBlockGraph$sub_refs	soot_toolkits_graph_CompleteBlockGraph;
    _jc_soot_toolkits_graph_BlockGraph$sub_refs	soot_toolkits_graph_BlockGraph;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_graph_CompleteBlockGraph$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_graph_CompleteBlockGraph$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_graph_BlockGraph$sub_nonrefs	soot_toolkits_graph_BlockGraph;
    _jc_soot_toolkits_graph_CompleteBlockGraph$sub_nonrefs	soot_toolkits_graph_CompleteBlockGraph;
};

// Object instance structure
struct _jc_soot_toolkits_graph_CompleteBlockGraph$object {
	_jc_soot_toolkits_graph_CompleteBlockGraph$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_graph_CompleteBlockGraph$vtype	*vtype;
	_jc_soot_toolkits_graph_CompleteBlockGraph$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_graph_CompleteBlockGraph$vtype _jc_soot_toolkits_graph_CompleteBlockGraph$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_graph_CompleteBlockGraph, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_graph_CompleteBlockGraph$class_object;

#endif	/* _JC_soot_toolkits_graph_CompleteBlockGraph_H_ */
